==> applovin-4.8.6-sources.jar: com/yodo1/mas/mediation/applovin/Yodo1MasAppLovinInterstitialAdapter.java <==
package com.yodo1.mas.mediation.applovin;

import android.app.Activity;

import com.applovin.adview.AppLovinInterstitialAd;
import com.applovin.adview.AppLovinInterstitialAdDialog;
import com.applovin.sdk.AppLovinAd;
import com.applovin.sdk.AppLovinAdClickListener;
import com.applovin.sdk.AppLovinAdDisplayListener;
import com.applovin.sdk.AppLovinAdLoadListener;
import com.applovin.sdk.AppLovinAdSize;
import com.applovin.sdk.AppLovinAdVideoPlaybackListener;
import com.applovin.sdk.AppLovinSdk;
import com.yodo1.mas.Yodo1MasLog;
import com.yodo1.mas.error.Yodo1MasError;
import com.yodo1.mas.interstitial.Yodo1MasInterstitialAdapterBase;
import com.yodo1.mas.mediation.Yodo1MasAdapterBase;

import java.util.List;

public class Yodo1MasAppLovinInterstitialAdapter extends Yodo1MasInterstitialAdapterBase {
    private final AppLovinAdVideoPlaybackListener interstitialPlayListener = new AppLovinAdVideoPlaybackListener() {
        @Override
        public void videoPlaybackBegan(AppLovinAd appLovinAd) {
            String message = "method: videoPlaybackBegan, interstitial: " + appLovinAd.getAdIdNumber();
            Yodo1MasLog.v(TAG, message);
        }

        @Override
        public void videoPlaybackEnded(AppLovinAd appLovinAd, double v, boolean b) {
            String message = "method: videoPlaybackEnded, interstitial: " + appLovinAd.getAdIdNumber();
            Yodo1MasLog.v(TAG, message);
        }
    };
    private final AppLovinAdDisplayListener interstitialDisplayListener = new AppLovinAdDisplayListener() {
        @Override
        public void adDisplayed(AppLovinAd appLovinAd) {
            String message = "method: adDisplayed, interstitial: " + appLovinAd.getAdIdNumber();
            Yodo1MasLog.v(TAG, message);
            callbackOpen();
        }

        @Override
        public void adHidden(AppLovinAd appLovinAd) {
            String message = "method: adHidden, interstitial: " + appLovinAd.getAdIdNumber();
            Yodo1MasLog.v(TAG, message);
            callbackClose();
        }
    };
    private final AppLovinAdClickListener interstitialClickListener = new AppLovinAdClickListener() {
        @Override
        public void adClicked(AppLovinAd appLovinAd) {
            String message = "method: adClicked, interstitial: " + appLovinAd.getAdIdNumber();
            Yodo1MasLog.v(TAG, message);
            callbackClick();
        }
    };
    private AppLovinAd interstitialAd;
    private final AppLovinAdLoadListener interstitialLoadListener = new AppLovinAdLoadListener() {
        @Override
        public void adReceived(AppLovinAd appLovinAd) {
            String message = "method: adReceived, interstitial: " + appLovinAd.getAdIdNumber();
            Yodo1MasLog.v(TAG, message);
            interstitialAd = appLovinAd;
            callbackLoad();
        }

        @Override
        public void failedToReceiveAd(int code) {
            String message = "method: failedToReceiveAd, error: " + code;
            Yodo1MasLog.v(TAG, message);
            Yodo1MasError error = new Yodo1MasError(Yodo1MasError.CODE_ADVERT_LOAD_FAIL, TAG + ":{" + message + "}");
            callbackError(error, code, message);
        }
    };

    public Yodo1MasAppLovinInterstitialAdapter(List<Yodo1MasAdapterBase.AdId> unitIds) {
        super(unitIds);
    }

    @Override
    public boolean isInterstitialAdLoaded() {
        return interstitialAd != null && super.isInterstitialAdLoaded();
    }

    @Override
    public void loadInterstitialAdvert(Activity activity) {
        super.loadInterstitialAdvert(activity);
        if (interstitialStatus == Yodo1MasAdapterBase.AdvertStatus.LOADING) return;
        interstitialStatus = Yodo1MasAdapterBase.AdvertStatus.LOADING;
        AppLovinSdk.getInstance(activity).getAdService().loadNextAd(AppLovinAdSize.INTERSTITIAL, interstitialLoadListener);
    }

    @Override
    public void showInterstitialAdvertFromActivity(Activity activity) {
        super.showInterstitialAdvertFromActivity(activity);
        if (isInterstitialAdLoaded()) {
            String message = "method: showInterstitialAdvert, show interstitial ad...";
            Yodo1MasLog.v(TAG, message);

            final AppLovinSdk sdk = AppLovinSdk.getInstance(activity);
            final AppLovinInterstitialAdDialog dialog = AppLovinInterstitialAd.create(sdk, activity);
            dialog.setAdDisplayListener(interstitialDisplayListener);
            dialog.setAdClickListener(interstitialClickListener);
            dialog.setAdVideoPlaybackListener(interstitialPlayListener);
            dialog.showAndRender(interstitialAd);
        }
    }
}

==> applovin-4.8.9-sources.jar: com/yodo1/mas/mediation/applovin/Yodo1MasAppLovinInterstitialAdapter.java <==
package com.yodo1.mas.mediation.applovin;

import android.app.Activity;

import com.applovin.adview.AppLovinInterstitialAd;
import com.applovin.adview.AppLovinInterstitialAdDialog;
import com.applovin.sdk.AppLovinAd;
import com.applovin.sdk.AppLovinAdClickListener;
import com.applovin.sdk.AppLovinAdDisplayListener;
import com.applovin.sdk.AppLovinAdLoadListener;
import com.applovin.sdk.AppLovinAdSize;
import com.applovin.sdk.AppLovinAdVideoPlaybackListener;
import com.applovin.sdk.AppLovinSdk;
import com.yodo1.mas.Yodo1MasLog;
import com.yodo1.mas.error.Yodo1MasError;
import com.yodo1.mas.interstitial.Yodo1MasInterstitialAdapterBase;
import com.yodo1.mas.mediation.Yodo1MasAdapterBase;

import java.util.List;

public class Yodo1MasAppLovinInterstitialAdapter extends Yodo1MasInterstitialAdapterBase {
    private final AppLovinAdVideoPlaybackListener interstitialPlayListener = new AppLovinAdVideoPlaybackListener() {
        @Override
        public void videoPlaybackBegan(AppLovinAd appLovinAd) {
            String message = "method: videoPlaybackBegan, interstitial: " + appLovinAd.getAdIdNumber();
            Yodo1MasLog.d(TAG, message);
        }

        @Override
        public void videoPlaybackEnded(AppLovinAd appLovinAd, double v, boolean b) {
            String message = "method: videoPlaybackEnded, interstitial: " + appLovinAd.getAdIdNumber();
            Yodo1MasLog.d(TAG, message);
        }
    };
    private final AppLovinAdDisplayListener interstitialDisplayListener = new AppLovinAdDisplayListener() {
        @Override
        public void adDisplayed(AppLovinAd appLovinAd) {
            String message = "method: adDisplayed, interstitial: " + appLovinAd.getAdIdNumber();
            Yodo1MasLog.d(TAG, message);
            callbackOpen();
        }

        @Override
        public void adHidden(AppLovinAd appLovinAd) {
            String message = "method: adHidden, interstitial: " + appLovinAd.getAdIdNumber();
            Yodo1MasLog.d(TAG, message);
            callbackClose();
        }
    };
    private final AppLovinAdClickListener interstitialClickListener = new AppLovinAdClickListener() {
        @Override
        public void adClicked(AppLovinAd appLovinAd) {
            String message = "method: adClicked, interstitial: " + appLovinAd.getAdIdNumber();
            Yodo1MasLog.d(TAG, message);
            callbackClick();
        }
    };
    private AppLovinAd interstitialAd;
    private final AppLovinAdLoadListener interstitialLoadListener = new AppLovinAdLoadListener() {
        @Override
        public void adReceived(AppLovinAd appLovinAd) {
            String message = "method: adReceived, interstitial: " + appLovinAd.getAdIdNumber();
            Yodo1MasLog.d(TAG, message);
            interstitialAd = appLovinAd;
            callbackLoad();
        }

        @Override
        public void failedToReceiveAd(int code) {
            String message = "method: failedToReceiveAd, error: " + code;
            Yodo1MasLog.d(TAG, message);
            Yodo1MasError error = new Yodo1MasError(Yodo1MasError.CODE_ADVERT_LOAD_FAIL, TAG + ":{" + message + "}");
            callbackError(error, code, message);
        }
    };

    public Yodo1MasAppLovinInterstitialAdapter(List<Yodo1MasAdapterBase.AdId> unitIds) {
        super(unitIds);
    }

    @Override
    public boolean isInterstitialAdLoaded() {
        return interstitialAd != null && super.isInterstitialAdLoaded();
    }

    @Override
    public void loadInterstitialAdvert(Activity activity) {
        super.loadInterstitialAdvert(activity);
        if (interstitialStatus == Yodo1MasAdapterBase.AdvertStatus.LOADING) return;
        interstitialStatus = Yodo1MasAdapterBase.AdvertStatus.LOADING;
        AppLovinSdk.getInstance(activity).getAdService().loadNextAd(AppLovinAdSize.INTERSTITIAL, interstitialLoadListener);
    }

    @Override
    public void showInterstitialAdvertFromActivity(Activity activity) {
        super.showInterstitialAdvertFromActivity(activity);
        if (isInterstitialAdLoaded()) {
            String message = "method: showInterstitialAdvert, show interstitial ad...";
            Yodo1MasLog.d(TAG, message);

            final AppLovinSdk sdk = AppLovinSdk.getInstance(activity);
            final AppLovinInterstitialAdDialog dialog = AppLovinInterstitialAd.create(sdk, activity);
            dialog.setAdDisplayListener(interstitialDisplayListener);
            dialog.setAdClickListener(interstitialClickListener);
            dialog.setAdVideoPlaybackListener(interstitialPlayListener);
            dialog.showAndRender(interstitialAd);
        }
    }
}
